==> haskell-threads-0.5.1.5-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-threads.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: threads
version: 0.5.1.5
id: threads-0.5.1.5-3aEOm2dRuGHDbWvYqrfCDR
key: threads-0.5.1.5-3aEOm2dRuGHDbWvYqrfCDR
license: BSD3
copyright: 2010–2012 Bas van Dijk & Roel van Dijk
maintainer: Bas van Dijk <v.dijk.bas@gmail.com>
            Roel van Dijk <vandijk.roel@gmail.com>
stability: experimental
homepage: https://github.com/basvandijk/threads
synopsis: Fork threads and wait for their result
description:
    This package provides functions to fork threads and
    wait for their result, whether it'\''s an exception or a
    normal value.
    .
    Besides waiting for the termination of a single thread
    this packages also provides functions to wait for a
    group of threads to terminate.
    .
    This package is similar to the
    @threadmanager@, @async@ and @spawn@ packages.
    The advantages of this package are:
    .
    * Simpler API.
    .
    * More efficient in both space and time.
    .
    * No space-leak when forking a large number of threads.
    .
    * Correct handling of asynchronous exceptions.
    .
    * GHC specific functionality like @forkOn@ and @forkIOWithUnmask@.
category: Concurrency
author: Bas van Dijk <v.dijk.bas@gmail.com>
        Roel van Dijk <vandijk.roel@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Control.Concurrent.Thread Control.Concurrent.Thread.Group
hidden-modules: Control.Concurrent.Raw
abi: 8c577ffe161cceb96c3bff7c7bc93db7
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/threads-0.5.1.5
library-dirs: /usr/lib/ghc-8.2.2/site-local/threads-0.5.1.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/threads-0.5.1.5
hs-libraries: HSthreads-0.5.1.5-3aEOm2dRuGHDbWvYqrfCDR
depends:
    base-4.10.1.0 stm-2.4.4.1-E6EjE1bszQZJ9orPdUNxjw
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             stm-2.4.4.1-E6EjE1bszQZJ9orPdUNxjw=05affb1c34b776a775422ef4ed6b6def
haddock-interfaces: /usr/share/doc/haskell-threads/html/threads.haddock
haddock-html: /usr/share/doc/haskell-threads/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-threads-0.5.1.6-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-threads.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: threads
version: 0.5.1.6
id: threads-0.5.1.6-2NpdBy0xfDH2xhif8hOk9S
key: threads-0.5.1.6-2NpdBy0xfDH2xhif8hOk9S
license: BSD3
copyright: 2010–2012 Bas van Dijk & Roel van Dijk
maintainer: Bas van Dijk <v.dijk.bas@gmail.com>
            Roel van Dijk <vandijk.roel@gmail.com>
stability: experimental
homepage: https://github.com/basvandijk/threads
synopsis: Fork threads and wait for their result
description:
    This package provides functions to fork threads and
    wait for their result, whether it'\''s an exception or a
    normal value.
    .
    Besides waiting for the termination of a single thread
    this packages also provides functions to wait for a
    group of threads to terminate.
    .
    This package is similar to the
    @threadmanager@, @async@ and @spawn@ packages.
    The advantages of this package are:
    .
    * Simpler API.
    .
    * More efficient in both space and time.
    .
    * No space-leak when forking a large number of threads.
    .
    * Correct handling of asynchronous exceptions.
    .
    * GHC specific functionality like @forkOn@ and @forkIOWithUnmask@.
category: Concurrency
author: Bas van Dijk <v.dijk.bas@gmail.com>
        Roel van Dijk <vandijk.roel@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Control.Concurrent.Thread Control.Concurrent.Thread.Group
hidden-modules: Control.Concurrent.Raw
abi: f705067da0d9706cea06c814e23f162f
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/threads-0.5.1.6
library-dirs: /usr/lib/ghc-8.2.2/site-local/threads-0.5.1.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/threads-0.5.1.6
hs-libraries: HSthreads-0.5.1.6-2NpdBy0xfDH2xhif8hOk9S
depends:
    base-4.10.1.0 stm-2.4.5.0-7j9Z9j03i0pHiTKIV2qS3x
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             stm-2.4.5.0-7j9Z9j03i0pHiTKIV2qS3x=ad99cb175fde1a67819ef6519a4015eb
haddock-interfaces: /usr/share/doc/haskell-threads/html/threads.haddock
haddock-html: /usr/share/doc/haskell-threads/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
